annot package
=============

Submodules
----------

annot.main module
-----------------

.. automodule:: annot.main
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: annot
    :members:
    :undoc-members:
    :show-inheritance:
